#!/usr/bin/env python
# -*- coding: utf-8 -*-
# ---------------------------------------------------
#       项目名: qazse   
#       文件名: __init__.py 
#       作者  : Qazse 
#       时间  : 2019/4/13
#       主页  : http://qiiing.com 
#       功能  :
# ---------------------------------------------------
import sys as _sys
import io
from qazse import file
from qazse import log
from qazse import requser
from qazse import seo
from qazse import text
from qazse import time
from qazse import file
from qazse import sys
from qazse import spiders
from qazse import db


_sys.stdout = io.TextIOWrapper(_sys.stdout.buffer, encoding='gb18030')
